@@ -4,3 +4,5 @@ from mrftools.sequenceGenerators import *
 from mrftools.dictionaryParameters import *
 from mrftools.sequenceParameters import *
 from mrftools.simulation import *
+from mrftools.phantomGenerators import *
+from mrftools.testing import *
\ No newline at end of file
