@@ -73,7 +73,7 @@ class DictionaryParameters:
         index = np.argmin(normedDiffs)
         return (index, self.entries[index])
 
-    def GetRegionNear(self, T1, T2, B1, T1Radius=-1, T2Radius=-1, B1Radius=-1):
+    def GetRegionNear(self, T1, T2, B1=1, T1Radius=-1, T2Radius=-1, B1Radius=-1):
         if T1Radius == -1:
             T1Radius = T1*0.1
         if T2Radius == -1:
@@ -120,7 +120,7 @@ class DictionaryParameters:
         return new_dictionary_parameters
 
     @staticmethod
-    def GenerateFixedPercent(name, t1Range=(100,4000), t2Range=(1,400), percentStepSize=5, includeB1=False, b1Range=(0.5,1.5), b1Stepsize=0.05):
+    def GenerateFixedPercent(name, t1Range=(100,5000), t2Range=(1,500), percentStepSize=5, includeB1=False, b1Range=(0.5,1.5), b1Stepsize=0.05):
         new_dictionary_parameters = DictionaryParameters(name)
         T1s = []
         T2s = []
@@ -150,7 +150,7 @@ class DictionaryParameters:
         return new_dictionary_parameters
 
     @staticmethod
-    def GenerateFixedStep(name, t1Range=(100,4000), t2Range=(1,400), fixedStepSize=1, includeB1=False, b1Range=(0.5,1.5), b1Stepsize=0.05):
+    def GenerateFixedStep(name, t1Range=(100,5000), t2Range=(1,500), fixedStepSize=1, includeB1=False, b1Range=(0.5,1.5), b1Stepsize=0.05):
         new_dictionary_parameters = DictionaryParameters(name)
         T1s = []
         T2s = []
